@@ -240,6 +240,7 @@ static int set_duid(struct connman_service *service,
 
 		hex_duid = convert_to_hex(duid, duid_len);
 		if (!hex_duid) {
+			g_free(duid);
 			g_key_file_free(keyfile);
 			return -ENOMEM;
 		}
@@ -446,7 +447,6 @@ static int check_ipv6_addr_prefix(GSList *prefixes, char *address)
 		if (!slash)
 			continue;
 
-		prefix = g_strndup(prefix, slash - prefix);
 		len = strtol(slash + 1, NULL, 10);
 		if (len < 3 || len > 128)
 			break;
@@ -457,6 +457,7 @@ static int check_ipv6_addr_prefix(GSList *prefixes, char *address)
 		left = plen % 8;
 		i = 16 - count;
 
+		prefix = g_strndup(prefix, slash - prefix);
 		inet_pton(AF_INET6, prefix, &addr_prefix);
 		inet_pton(AF_INET6, address, &addr);
 
@@ -505,7 +506,7 @@ static int set_other_addresses(GDHCPClient *dhcp_client,
 			for (i = 0, list = option; list;
 						list = list->next, i++)
 				domains[i] = g_strdup(list->data);
-			__connman_service_update_search_domains(service, domains);
+			__connman_service_set_search_domains(service, domains);
 			g_strfreev(domains);
 		}
 	}
@@ -1107,7 +1108,7 @@ static void re_cb(enum request_type req_type, GDHCPClient *dhcp_client,
 			if (!option) {
 				switch (req_type) {
 				case REQ_REQUEST:
-					dhcpv6_request(dhcp, true);
+					do_resend_request(dhcp);
 					break;
 				case REQ_REBIND:
 					dhcpv6_rebind(dhcp);
@@ -1192,6 +1193,11 @@ static int check_restart(struct connman_dhcpv6 *dhcp)
 
 	g_dhcpv6_client_get_timeouts(dhcp->dhcp_client, NULL, NULL,
 				NULL, &expired);
+
+	/* infinite lifetime for an DHCPv6 address */
+	if (expired == 0xffffffff)
+		return -EISCONN;
+
 	current = time(NULL);
 
 	if (current >= expired) {
@@ -1682,9 +1688,16 @@ static void solicitation_cb(GDHCPClient *dhcp_client, gpointer user_data)
 
 	clear_timer(dhcp);
 
-	do_dad(dhcp_client, dhcp);
-
 	g_dhcpv6_client_clear_retransmit(dhcp_client);
+
+	if (g_dhcpv6_client_get_status(dhcp_client) != 0) {
+		if (dhcp->callback)
+			dhcp->callback(dhcp->network,
+					CONNMAN_DHCPV6_STATUS_FAIL, NULL);
+		return;
+	}
+
+	do_dad(dhcp_client, dhcp);
 }
 
 static gboolean timeout_solicitation(gpointer user_data)
