@@ -50,6 +50,7 @@ struct connman_network {
 	bool available;
 	bool connected;
 	bool roaming;
+	bool connectable;
 	uint8_t strength;
 	uint16_t frequency;
 	char *identifier;
@@ -825,6 +826,18 @@ static gint compare_priority(gconstpointer a, gconstpointer b)
 	return driver2->priority - driver1->priority;
 }
 
+int connman_network_set_connectable(struct connman_network *network,
+		bool connectable)
+{
+	network->connectable = connectable;
+	return 0;
+}
+
+bool connman_network_get_connectable(struct connman_network *network)
+{
+	return network->connectable;
+}
+
 /**
  * connman_network_driver_register:
  * @driver: network driver definition
