@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2012  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2013  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -148,6 +148,10 @@ int connman_provider_disconnect(struct connman_provider *provider)
 		return -EINPROGRESS;
 	}
 
+	if (provider->vpn_service)
+		provider_indicate_state(provider,
+					CONNMAN_SERVICE_STATE_IDLE);
+
 	return 0;
 }
 
@@ -164,14 +168,15 @@ int connman_provider_remove(struct connman_provider *provider)
 	return 0;
 }
 
-int __connman_provider_connect(struct connman_provider *provider)
+int __connman_provider_connect(struct connman_provider *provider,
+					const char *dbus_sender)
 {
 	int err;
 
 	DBG("provider %p", provider);
 
 	if (provider->driver && provider->driver->connect)
-		err = provider->driver->connect(provider);
+		err = provider->driver->connect(provider, dbus_sender);
 	else
 		return -EOPNOTSUPP;
 
