@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2012  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -102,7 +102,7 @@ static void lease_available_cb(GDHCPClient *dhcp_client, gpointer user_data)
 
 	address = g_dhcp_client_get_address(dhcp_client);
 	printf("address %s\n", address);
-	if (address == NULL)
+	if (!address)
 		return;
 
 	option_value = g_dhcp_client_get_option(dhcp_client, G_DHCP_SUBNET);
@@ -143,7 +143,7 @@ int main(int argc, char *argv[])
 	printf("Create DHCP client for interface %d\n", index);
 
 	dhcp_client = g_dhcp_client_new(G_DHCP_IPV4, index, &error);
-	if (dhcp_client == NULL) {
+	if (!dhcp_client) {
 		handle_error(error);
 		exit(0);
 	}
@@ -170,7 +170,7 @@ int main(int argc, char *argv[])
 
 	timer = g_timer_new();
 
-	g_dhcp_client_start(dhcp_client);
+	g_dhcp_client_start(dhcp_client, NULL);
 
 	memset(&sa, 0, sizeof(sa));
 	sa.sa_handler = sig_term;
